##########
#
#  Copyright 2002, Tom Hoffman.
# 
#  This file is part of Tuttle.
#
#  Tuttle is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  Tuttle is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Tuttle (see COPYING.txt); if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##########

from OFS.Folder import Folder
from AdministratorPersonal import AdministratorPersonal
from Globals import DTMLFile, InitializeClass
from AccessControl import ClassSecurityInfo
import string



class AdministratorsFolder(Folder):
	"These objects contain individual administrators folders."
	
	meta_type="Administrators Folder"
	
	_properties=(
	{'id':'title', 'type':'string'},
	)

	manage_options=Folder.manage_options[:3] + (
	{'label':'Add Administrator','action':'manage_addAdministratorPersonalForm'},
	) + Folder.manage_options[3:]


	def __init__ (self,id,title):
		self.id=id
		self.title=title
	
        # set up security boilerplate
        security = ClassSecurityInfo()
        security.setDefaultAccess("deny")
        __roles__ = ()


	# methods to add, edit and retrieve AdministratorPersonal instances

	security.declareProtected('Manage School', 'addAdministratorPersonal')
	def addAdministratorPersonal(self, id, FirstName, LastName, MiddleName, PreferredName, \
	Prefix, Suffix, Title, Gender, REQUEST=None):
		"Method to add a AdministratorPersonal object to a AdministratorFolder"
		# see StudentsFolder.addStudentPersonal for documentation
		newAdministratorPersonal=AdministratorPersonal(id, FirstName, LastName, MiddleName, \
		PreferredName, Prefix, Suffix, Title, Gender) 
		newAdministratorPersonal.manage_setLocalRoles(id,['Owner'])
		self._setObject(id, newAdministratorPersonal)
		self.addNewTuttleUser(id, ['administrator'], [])
		if REQUEST is not None:
			return self.manage_main(self, REQUEST)


	# web presentation methods
	security.declareProtected('View management screens', 'manage_addAdministratorPersonalForm')
	manage_addAdministratorPersonalForm=DTMLFile("dtml/addAdministratorPersonalForm",globals())

InitializeClass(AdministratorPersonal)
