##########
#
#  Copyright 2002, Tom Hoffman.
# 
#  This file is part of Tuttle.
#
#  Tuttle is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  Tuttle is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Tuttle (see COPYING.txt); if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##########

from OFS.Folder import Folder
from Globals import DTMLFile, InitializeClass
from Products.ZCatalog.CatalogPathAwareness import CatalogAware
from Acquisition import Implicit
from AccessControl import ClassSecurityInfo

class StudentPersonal(CatalogAware, Folder):
	"The basic container for a student's objects, with some basic attributes"
	meta_type = "student"
	
	_properties=(
	{'id':'title','type':'string'},
	{'id':'FirstName','type':'string'},
	{'id':'LastName','type':'string'},
	{'id':'MiddleName','type':'string'},
	{'id':'PreferredName','type':'string'},
	{'id':'Suffix','type':'string'},
	{'id':'Gender','type':'selection','select_variable':'Genders'},
	{'id':'GradeLevel','type':'selection','select_variable':'GradeLevelList'},
	{'id':'GradYear','type':'selection','select_variable':'GradYearList'},
	{'id':'Team','type':'selection','select_variable':'TeamList'},
	)
	
	manage_options=Folder.manage_options[:3] + (
        {'label':'Class Schedule','action':'StudentClassSchedule'},
        ) + Folder.manage_options[3:]

	def __init__ (self, id, FirstName, LastName, MiddleName="", PreferredName="", \
	Suffix="", Gender="?", GradeLevel="?", GradYear="?", Team="?", REQUEST=None):
		self.id=id
		self.editStudentPersonal(FirstName, LastName, MiddleName, PreferredName, \
		Suffix, Gender, GradeLevel, GradYear,Team)
	
        # set up security boilerplate
        security = ClassSecurityInfo()
        security.setDefaultAccess("deny")
        __roles__ = ()
	
	security.declareProtected('Manage School', 'editStudentPersonal')
	def editStudentPersonal (self, FirstName, LastName, MiddleName, PreferredName, \
	Suffix, Gender, GradeLevel, GradYear, Team, REQUEST=None):
		"Method for updating student personal data"
		self.FirstName=FirstName
		self.MiddleName=MiddleName
		self.LastName=LastName
		self.PreferredName=PreferredName
		if self.title[-7:] != 'Records':
			if self.PreferredName != "":
				self.title=PreferredName+"\'s Records" 
			else:
				self.title=FirstName+"\'s Records"             
		self.Suffix=Suffix
		self.Gender=Gender
		self.GradeLevel=GradeLevel
		self.GradYear=GradYear
		self.Team=Team
		self.reindex_object()
		if REQUEST is not None:
			return self.index_html(self,REQUEST) 
	

	security.declareProtected('Access Student Schedule', 'getSchedule')	
	def getSchedule(self,studid):
		"Returns a list of classes with this student on the roster"
		x = self.Catalog({'Roster':studid})
		z=[]
		for y in x:
			z.append(y.getObject())
		return z

	# Web Presentation Methods
	security.declareProtected('View', 'index_html')
	index_html=DTMLFile("dtml/indexStudentPersonal",globals())
	security.declareProtected('Access Student Schedule', 'getSchedule')
	StudentClassSchedule=DTMLFile("dtml/StudentClassSchedule", globals())

	security.setPermissionDefault('Access Student Schedule',\
	['Manager', 'teacher', 'administrator', 'guardian', 'Owner'])

InitializeClass(StudentPersonal)
