##########
#
#  Copyright 2002, Tom Hoffman.
# 
#  This file is part of Tuttle.
#
#  Tuttle is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  Tuttle is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Tuttle (see COPYING.txt); if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##########

from OFS.Folder import Folder
from Globals import DTMLFile, InitializeClass
from TeacherClass import TeacherClass
from Products.ZCatalog.CatalogPathAwareness import CatalogAware
from AccessControl import ClassSecurityInfo

class TeacherPersonal(CatalogAware, Folder):
	"The basic container for a teacher's objects, with some basic attributes"
	meta_type = "teacher"
	
	_properties=(
	{'id':'title','type':'string'},
	{'id':'FirstName','type':'string'},
	{'id':'LastName','type':'string'},
	{'id':'MiddleName','type':'string'},
	{'id':'PreferredName','type':'string'},
	{'id':'Prefix','type':'string'},
	{'id':'Suffix','type':'string'},
	{'id':'Gender','type':'selection','select_variable':'Genders'},
	{'id':'Team','type':'selection','select_variable':'TeacherTeamList'},
	)
	
	manage_options=Folder.manage_options[:3] + (
	{'label':'Add Class','action':'manage_addTeacherClassForm'},
	) + Folder.manage_options[3:]



	def __init__ (self, id, FirstName, LastName, MiddleName="", PreferredName="", \
	Prefix="", Suffix="", Gender="?", Team="?", REQUEST=None):
		self.id=id
		self.editTeacherPersonal(FirstName, LastName, MiddleName, PreferredName, \
		Prefix, Suffix, Gender, Team)

        # set up security boilerplate
        security = ClassSecurityInfo()
        security.setDefaultAccess("deny")
        __roles__ = ()

	security.declareProtected('Manage School', 'editTeacherPersonal')
	def editTeacherPersonal (self, FirstName, LastName, MiddleName, PreferredName, \
	Prefix, Suffix, Gender, Team, REQUEST=None):
		"Method for updating teacher personal data"
		self.FirstName=FirstName
		self.MiddleName=MiddleName
		self.LastName=LastName
		self.PreferredName=PreferredName
		if self.title[-7:] != 'Files':
			if self.PreferredName != "":
				self.title=PreferredName+"\'s Files" 
			else:
				self.title=FirstName+"\'s Files"             
		self.Suffix=Suffix
		self.Prefix=Prefix
		self.Gender=Gender
		self.Team=Team
		self.reindex_object()
		if REQUEST is not None:
			return self.index_html(self,REQUEST) 
	
	security.declareProtected('Manage Classes', 'addTeacherClass')
	def addTeacherClass(self, id, title, CourseName, Subject, Level, Period, Description, REQUEST=None):
		"Method to add a TeacherClass object to a Teacher Folder"
		newTeacherClass=TeacherClass(id, CourseName, Subject, Level, Period, Description)
		self._setObject(id, newTeacherClass)
		if REQUEST is not None:
			return self.manage_main(self, REQUEST)



	# Web Presentation Methods
	security.declareProtected('View', 'index_html')
	index_html=DTMLFile("dtml/indexTeacherPersonal",globals())
	security.declareProtected('Manage Classes', 'manage_addTeacherClassForm')
	manage_addTeacherClassForm=DTMLFile("dtml/addTeacherClassForm",globals())

	security.setPermissionDefault('Manage Classes', ['Manager', 'Administrator'])

InitializeClass(TeacherPersonal)
